@@ -29,6 +29,7 @@ class Common(object):
         self.message = None
         self.feature_name = None
         self.data = None
+        self.user_id = None
         self.storage_info_from_set = OrderedDict()
         self.workspace_alarm_api = WorkspaceRestApi(env_value[LcConst.BACK_END_API_URL],
                                                     env_value[LcConst.BACK_END_API_PORT],
@@ -269,6 +270,12 @@ class Common(object):
         self.message = None
         self.thresholds = None
 
+    def set_user_id(self, user_id):
+        self.user_id = user_id
+
+    def unset_user_id(self):
+        self.user_id = None
+
     def set_features(self, feature_names):
         if str(type(feature_names)) == "<class 'list'>":
             self.feature_name = feature_names
