@@ -91,11 +91,12 @@ def _parse_true_predict(metric_data, metrics):
 def parse_run_parameters(json_data):
     # read ~/runs/results-XGBClassifier/model-info-json/*.json
     # return parameters
-
     param_data = json_data['json']
-    if SELECTED_PARAMS in param_data:
-        selected_params = param_data[SELECTED_PARAMS]
+    grpc_params = []
+    if SELECTED_PARAMS not in param_data:
+        return grpc_params
 
+    selected_params = param_data[SELECTED_PARAMS]
     all_model_params = param_data[ALL_MODEL_PARAMS]
 
     grpc_params = _makeLcParam(selected_params=selected_params, all_model_params=all_model_params)
@@ -107,6 +108,52 @@ def parse_run_parameters(json_data):
 
 
 # parse metrics
+def _parse_selected_metrics(json_data):
+    # read ~/runs/results-XGBClassifier/model-info-json/*.json
+    # get "selected_metrics" field
+    # return metrics
+
+    metric_data = json_data['json']
+
+    grpc_metrics = []
+    if SELECTED_METRICS not in metric_data:
+        return grpc_metrics
+
+    # selected_metrics
+    selected_metrics = metric_data[SELECTED_METRICS]
+    metric_keys = selected_metrics.keys()
+
+    result_dict = {'metrics': []}
+
+    count = 0
+    timestamp = []
+    steps = []
+    values = []
+    for key in metric_keys:
+        values.append(str(selected_metrics[key]))
+        timestamp.append(str(count))
+        steps.append(key)
+        count += 1
+
+    result_dict['metrics'].append({
+                                   'values': values,
+                                   'timestamp': timestamp,
+                                   'steps': steps})
+
+    metrics = result_dict['metrics']
+
+    for item in metrics:
+        metric = LcMetric(
+                key=SELECTED_METRICS,
+                values=item['values'],
+                timestamp=item['timestamp'],
+                steps=item['steps']
+            )
+        grpc_metrics.append(metric)
+
+    return grpc_metrics
+
+
 def parse_run_metrics(json_data):
     # read ~/runs/results-XGBClassifier/model-info-json/*.json
     # get "selected_metrics" field
@@ -114,6 +161,8 @@ def parse_run_metrics(json_data):
 
     metric_data = json_data['json']
     grpc_metrics = []
+    if SELECTED_METRICS not in metric_data:
+        return grpc_metrics
 
     # selected_metrics
     selected_metrics = metric_data[SELECTED_METRICS]
@@ -150,6 +199,9 @@ def parse_run_metrics(json_data):
             )
         grpc_metrics.append(metric)
 
+    selected_metrics = _parse_selected_metrics(json_data=json_data)
+    grpc_metrics = grpc_metrics + selected_metrics
+
     return grpc_metrics
 
 
@@ -191,8 +243,6 @@ def parse_run_result():
     grpc_params = parse_run_parameters(json_data=result_data)
     grpc_metrics = parse_run_metrics(json_data=result_data)
 
-    result_dict['params'] = grpc_params
-    result_dict['metrics'] = grpc_metrics
     for i in range(len(grpc_params)):
         if grpc_params[i].key == 'data_version':
             result_dict['artifact'] = {}
@@ -201,5 +251,8 @@ def parse_run_result():
             del grpc_params[i]
             break
 
+    result_dict['params'] = grpc_params
+    result_dict['metrics'] = grpc_metrics
+
     return result_dict
 
